@@ -14,6 +14,7 @@ from .version import VERSION, VERSION_INFO
 __author__ = 'EasyPost <oss@easypost.com>'
 __version__ = VERSION
 version_info = VERSION_INFO
+SUPPORT_EMAIL = 'support@easypost.com'
 
 
 # use urlfetch as request_lib on google app engine, otherwise use requests
@@ -35,7 +36,7 @@ except ImportError:
     except ImportError:
         raise ImportError('EasyPost requires an up to date requests library. '
                           'Update requests via "pip install -U requests" or '
-                          'contact us at contact@easypost.com.')
+                          'contact us at {}.'.format(SUPPORT_EMAIL))
 
     try:
         version = requests.__version__
@@ -43,12 +44,12 @@ except ImportError:
     except Exception:
         raise ImportError('EasyPost requires an up to date requests library. '
                           'Update requests via "pip install -U requests" or contact '
-                          'us at contact@easypost.com.')
+                          'us at {}.'.format(SUPPORT_EMAIL))
     else:
         if major < 1:
             raise ImportError('EasyPost requires an up to date requests library. Update '
                               'requests via "pip install -U requests" or contact us '
-                              'at contact@easypost.com.')
+                              'at {}.'.format(SUPPORT_EMAIL))
 
 # config
 api_key = None
@@ -152,6 +153,31 @@ def convert_to_easypost_object(response, api_key, parent=None, name=None):
         return response
 
 
+def _utf8(value):
+    if six.PY2:
+        # Python2's urlencode wants bytestrings, not unicode
+        if isinstance(value, six.text_type):
+            return value.encode('utf-8')
+        return value
+    elif isinstance(value, six.binary_type):
+        # Python3's six.text_type(bytestring) returns "b'bytestring'"
+        # So, have to decode it to unicode
+        return value.decode('utf-8')
+    else:
+        # Python3's urlencode can handle unicode
+        return value
+
+
+def _urlencode_list(params):
+    encoded = []
+    for key, values in sorted(params.items()):
+        for value in values:
+            if isinstance(value, bool):
+                value = str(value).lower()
+            encoded.append('{0}[]={1}'.format(key, quote_plus(_utf8(value))))
+    return '&'.join(encoded)
+
+
 class Requestor(object):
     def __init__(self, local_api_key=None):
         self._api_key = local_api_key
@@ -161,27 +187,12 @@ class Requestor(object):
         url = url or ''
         return '%s%s' % (api_base, url)
 
-    @classmethod
-    def _utf8(cls, value):
-        if six.PY2:
-            # Python2's urlencode wants bytestrings, not unicode
-            if isinstance(value, six.text_type):
-                return value.encode('utf-8')
-            return value
-        elif isinstance(value, six.binary_type):
-            # Python3's six.text_type(bytestring) returns "b'bytestring'"
-            # So, have to decode it to unicode
-            return value.decode('utf-8')
-        else:
-            # Python3's urlencode can handle unicode
-            return value
-
     @classmethod
     def encode_dict(cls, out, key, dict_value):
         n = {}
         for k, v in sorted(six.iteritems(dict_value)):
-            k = cls._utf8(k)
-            v = cls._utf8(v)
+            k = _utf8(k)
+            v = _utf8(v)
             n["%s[%s]" % (key, k)] = v
         out.extend(cls._encode_inner(n))
 
@@ -189,7 +200,7 @@ class Requestor(object):
     def encode_list(cls, out, key, list_value):
         n = {}
         for k, v in enumerate(list_value):
-            v = cls._utf8(v)
+            v = _utf8(v)
             n["%s[%s]" % (key, k)] = v
         out.extend(cls._encode_inner(n))
 
@@ -217,7 +228,7 @@ class Requestor(object):
 
         out = []
         for key, value in sorted(six.iteritems(params)):
-            key = cls._utf8(key)
+            key = _utf8(key)
             try:
                 encoder = ENCODERS[value.__class__]
                 encoder(out, key, value)
@@ -276,7 +287,7 @@ class Requestor(object):
             raise Error(
                 'No API key provided. Set an API key via "easypost.api_key = \'APIKEY\'. '
                 'Your API keys can be found in your EasyPost dashboard, or you can email us '
-                'at contact@easypost.com for assistance.')
+                'at {} for assistance.'.format(SUPPORT_EMAIL))
 
         abs_url = self.api_url(url)
         params = self._objects_to_ids(params)
@@ -314,8 +325,8 @@ class Requestor(object):
         elif request_lib == 'requests':
             http_body, http_status = self.requests_request(method, abs_url, headers, params)
         else:
-            raise Error("Bug discovered: invalid request_lib: %s. "
-                        "Please report to contact@easypost.com." % request_lib)
+            raise Error("Bug discovered: invalid request_lib: {}. "
+                        "Please report to {}.".format(request_lib, SUPPORT_EMAIL))
 
         return http_body, http_status, my_api_key
 
@@ -337,8 +348,8 @@ class Requestor(object):
         elif method == 'post' or method == 'put':
             data = self.encode(params)
         else:
-            raise Error("Bug discovered: invalid request method: %s. "
-                        "Please report to contact@easypost.com." % method)
+            raise Error("Bug discovered: invalid request method: {}. "
+                        "Please report to {}.".format(method, SUPPORT_EMAIL))
 
         try:
             result = requests_session.request(
@@ -353,7 +364,7 @@ class Requestor(object):
             http_status = result.status_code
         except Exception as e:
             raise Error("Unexpected error communicating with EasyPost. If this "
-                        "problem persists please let us know at contact@easypost.com.",
+                        "problem persists please let us know at {}.".format(SUPPORT_EMAIL),
                         original_exception=e)
         return http_body, http_status
 
@@ -364,8 +375,8 @@ class Requestor(object):
         elif method == 'get' or method == 'delete':
             abs_url = self.build_url(abs_url, params)
         else:
-            raise Error("Bug discovered: invalid request method: %s. Please report "
-                        "to contact@easypost.com." % method)
+            raise Error("Bug discovered: invalid request method: {}. Please report "
+                        "to {}.".format(method, SUPPORT_EMAIL))
 
         args['url'] = abs_url
         args['method'] = method
@@ -377,7 +388,7 @@ class Requestor(object):
             result = urlfetch.fetch(**args)
         except Exception as e:
             raise Error("Unexpected error communicating with EasyPost. "
-                        "If this problem persists, let us know at contact@easypost.com.",
+                        "If this problem persists, let us know at {}.".format(SUPPORT_EMAIL),
                         original_exception=e)
 
         return result.content, result.status_code
@@ -574,7 +585,7 @@ class Resource(EasyPostObject):
         easypost_id = self.get('id')
         if not easypost_id:
             raise Error('%s instance has invalid ID: %r' % (type(self).__name__, easypost_id))
-        easypost_id = Requestor._utf8(easypost_id)
+        easypost_id = _utf8(easypost_id)
         base = self.class_url()
         param = quote_plus(easypost_id)
         return "{base}/{param}".format(base=base, param=param)
@@ -634,13 +645,15 @@ class Address(AllResource, CreateResource):
         requestor = Requestor(api_key)
         url = cls.class_url()
 
-        if verify or verify_strict:
-            verify = verify or []
-            verify_strict = verify_strict or []
-            url += '?' + '&'.join(
-                ['verify[]={0}'.format(opt) for opt in verify] +
-                ['verify_strict[]={0}'.format(opt) for opt in verify_strict]
-            )
+        verify_params = {}
+        for key, value in (('verify', verify), ('verify_strict', verify_strict)):
+            if not value:
+                continue
+            elif isinstance(value, (bool, str)):
+                value = [value]
+            verify_params[key] = value
+        if verify_params:
+            url += '?' + _urlencode_list(verify_params)
 
         wrapped_params = {cls.class_name(): params}
         response, api_key = requestor.request('post', url, wrapped_params)
@@ -874,13 +887,6 @@ class Tracker(AllResource, CreateResource):
         response, api_key = requestor.request('post', url, params)
         return True
 
-    @classmethod
-    def all_updated(cls, api_key=None, **params):
-        requestor = Requestor(api_key)
-        url = "%s/%s" % (cls.class_url(), "all_updated")
-        response, api_key = requestor.request('get', url, params)
-        return convert_to_easypost_object(response["trackers"], api_key), response["has_more"]
-
 
 class Pickup(CreateResource):
     def buy(self, **params):
